/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007, 2009. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/

(function() {

dojo.provide("jazz.ui.RemoteChooserContainer");

/*
 * Imports
 */
dojo.require("dijit._Widget");
dojo.require("dijit._Templated");

/*
 * Local functions/vars
 */
var _PROTOCOL_WINDOWNAME = '#oslc-windowName-1.0';
var _PROTOCOL_POSTMSG = '#oslc-postMessage-1.0';
var _MESSAGE_PORT = "oslc-response:";

function _requiredArgument(/*Map*/ args, /*String*/ id) {
	if (!args[id])
		throw new Error('Missing required argument: "' + id + '"');
	try {
		return args[id];
	} finally {
		delete args[id];
	}
}

dojo.declare("jazz.ui.RemoteChooserContainer", [dijit._Widget, dijit._Templated], {
	
	//	summary:
	//		A wrapper widget for displaying and communicating with a webpage from another origin,
	//		which is hosted inside an IFrame. The domNode of this widget is undefined, but is
	//		guaranteed to be a block-level element with a relative width and height of 100%.
	//	example:
	//		var container = new jazz.ui.RemoteChooserContainer({
	//			remoteLocation: someRemoteUrl,
	//			onData: myCallback
	//		}, placeHolder);
	//	since:
	//		0.7
	
	//	_remoteURL: [private] String
	//		The URL (as a string) of the remote webpage initially displayed
	_remoteURL: null,
	
	//	_callback: [private] Function
	//		The callback function
	_callback: null,

	templatePath: dojo.moduleUrl("jazz.ui", "templates/RemoteChooserContainer.html"),
	
	constructor: function(args) {
		this._remoteURL = _requiredArgument(args, 'remoteLocation');
		this._callback = _requiredArgument(args, 'onData');
		this._count = jazz.ui.RemoteChooserContainer._counter++;
	},
	
	postCreate: function() {
		var doc = dojo.doc;
		var self = this;
		var isWindowName = !(dojo.isSafari >= 4 || dojo.isFF >= 3); // && dojo.isIE < 8;
		var returnLocation = new dojo._Url(window.location,
				dojo.moduleUrl("dojo", "resources/blank.html")).toString();
		
		var elementString = 'iframe';
		
		if (dojo.isIE && isWindowName)
			elementString = dojo.string.substitute(
				'<iframe name="${0}" onload="jazz.ui.RemoteChooserContainer._onLoad[${1}]()">',
				[returnLocation, this._count]);
		
		var frame = doc.createElement(elementString);
		
		if (isWindowName) {
			frame.name = returnLocation;
			var finished = false;
			
			jazz.ui.RemoteChooserContainer._onLoad[this._count] = frame.onload = function() {
				if (!finished) {
					try {
						if (frame.contentWindow.location != returnLocation)
							return;
						var data = frame.contentWindow.name;
						finished = true;
						self._callback(data);
					} catch (e) {
						//Ignore location changes on the remote server
					};
				}
			};
		} else {
			window.addEventListener('message',
				this._listener = function(e) {
					if (e.source == frame.contentWindow
							&& e.data.indexOf(_MESSAGE_PORT) == 0)
						self._callback(e.data.substr(_MESSAGE_PORT.length));
				},
				false);
		}
		
		dojo.style(frame, 'width', '100%');
		dojo.style(frame, 'height', '100%');
		frame.frameBorder = '0';
		frame.marginWidth = '0';
		frame.marginHeight = '0';
		
		frame.src = this._remoteURL + (isWindowName ? _PROTOCOL_WINDOWNAME : _PROTOCOL_POSTMSG);
		this._iframeDiv.appendChild(frame);
	},
	
	destroy: function() {
		try {
			if (jazz.ui.RemoteChooserContainer._onLoad[this._count])
				delete jazz.ui.RemoteChooserContainer._onLoad[this._count];
			if (this._listener)
				window.removeEventListener('message', this._listener, false);
		} finally {
			this.inherited('destroy', arguments);
		}
	}
});

/*
 * Globals
 */
jazz.ui.RemoteChooserContainer._counter = 0;
jazz.ui.RemoteChooserContainer._onLoad = [];

})();
