/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2009. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("jazz.app.internal.LoginDialog");

dojo.require("dojo.cookie");

dojo.require("jazz.app.internal.LoginText");
dojo.require("jazz.app.internal.LoginWidget");
dojo.require("jazz.app.internal.loginUtil");
dojo.require("jazz.ui.Dialog");
dojo.require("jazz.ui.styledBox.TrimStyles");

dojo.declare("jazz.app.internal.LoginDialog", null, {
	
	constructor: function(args) {
		
		var dialog = null;
		var loginWidget = null;
		
		//
		// API classes and methods
		//
				
		this.destroy = function() {
			// summary
			//		Destroys the internal state of the login dialog.
			if(loginWidget) {
				loginWidget.destroy();
			}
			if(dialog) {
				dialog.destroy();
			}
		};

		/*=====
		__getCredentialsArgs = {
			//	onSubmit: Function
			//		Callback invoked when the user submits credentials;
			//		argument of this callback is an instance of
			//		__getCredentialsCallbackArgs (see below)
			//	onCancel: Function
			//		Callback invoked if the user declines to provide;
			//		argument of this callback is null
			//	state: String, optional
			//		Indicates the state of the login interaction, if any. The
			//		only currently valid value is "login-failed".
		}
		=====*/
		/*=====
		__getCredentialsCallbackArgs = {
			//	userId: String
			//		the user ID submitted by the user; null if the user did not
			//		submit credentials
			//	password: String
			//		the password submitted by the user; null if the user did not
			//		submit credentials
		}
		=====*/
		
		this.getCredentials = function(/*__getCredentialsArgs*/args) {
			// summary
			//		Requests the login dialog to fetch credentials (user id and
			//		password) from the user.
			this.destroy();
			if(!dojo.isFunction(args.onSubmit)) {
				throw new Error("Argument 'args.onSubmit' is missing or not a function");
			}
			if(!dojo.isFunction(args.onCancel)) {
				throw new Error("Argument 'args.onCancel' is missing or not a function");
			}
			
			var mode = jazz.app.internal.loginUtil.getLoginMode();
			
			if(mode === "frame") {
				this.showTextLogin(args);
			} else {
				this.showDialogLogin(args);
			}
		
			// Allow retries since the user can cancel this log in dialog
			this.retryOnFailure = true;
		};
		
		this.showDialogLogin = function(args) {
			loginWidget = new jazz.app.internal.LoginWidget(
				{
					onSubmit: function(userId, password) {
						dialog.onClose = null;
						dialog.close();
						args.onSubmit(userId, password);
					},
					state: args.state
				},
				document.createElement("div"));
			
			var dialogArgs = {
				contentNode: loginWidget.domNode,
				onClose: function() {
					args.onCancel();
				},
				onOpen: dojo.hitch(loginWidget,loginWidget.startup),
				width: "580px",
				trim: jazz.ui.styledBox.TrimStyles.LOGIN
			};
			if (jazz.app.currentApplication && !jazz.app.currentApplication.started) {
				dialogArgs.closable = false;
			}
			dialog = new jazz.ui.Dialog(dialogArgs);
		};
		
		this.showTextLogin = function(args) {
			function swapNodes(source, target) {
				while(source.hasChildNodes()){
					var tmp = source.removeChild(source.firstChild);
					target.appendChild(tmp);
				}
			}
			var hiddenDiv = document.createElement("div");
			swapNodes(dojo.body(), hiddenDiv);
			loginWidget = new jazz.app.internal.LoginText({
				onSubmit: function(userId, password) {
					args.onSubmit(userId, password);
					dojo.body().removeChild(loginWidget.domNode);
					swapNodes(hiddenDiv, dojo.body());
				},
				state: args.state
			});
			dojo.body().appendChild(loginWidget.domNode);
		};
	}
	
});

})();
