/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2009. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("jazz.app.internal.LoginWidget");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dijit.form.Button");
dojo.require("dijit.form.CheckBox");
dojo.require("dijit.form.TextBox");

dojo.require("jazz.app.internal.loginUtil");

dojo.requireLocalization("jazz.app.internal", "LoginWidgetMessages");
	
dojo.declare("jazz.app.internal.LoginWidget", [dijit._Widget, dijit._Templated], {
	
	templatePath: dojo.moduleUrl("jazz.app", "internal/templates/LoginWidget.html"),
	widgetsInTemplate: true,
	
	constructor: function() {
		this.messages = dojo.i18n.getLocalization("jazz.app.internal", "LoginWidgetMessages");
	},
	
	postCreate: function() {
		this.inherited(arguments);
		this._origWindowTitle = document.title;
		document.title = this.messages.loginTitle;
		// show saved user ID, if present
		var userIdCookieVal = jazz.app.internal.loginUtil.getUserIdCookie();
		this.userId.attr('value', userIdCookieVal || "");
		this.rememberUserId.attr('value', userIdCookieVal ? true : false);
		
		//propagate any hash to the form so it doesn't get lost
		this.loginForm.action += jazz.app.internal.loginUtil.getLocationHash();
		
		// show error message, if necessary
		if(this.state === "login-failed") {
			this.loginErrorDiv.style.visibility = "visible";
			this.loginErrorDiv.appendChild(document.createTextNode(this.messages.invalidCredentials));
		}
		var app = jazz.app.currentApplication;
		if (app) {
			var productName = app.productName;
			var productIcon = app.productIconSmall;
			this._services.innerHTML = "<li><img src=\""+productIcon+"\"/>"+productName+"</li>";
			this._servicesArea.style.display = "block";
		}
		var hostname = window.location.hostname;
		var realm = net.jazz.ajax._oauthRealmName;
		this._serverInfo.innerHTML = realm ? dojo.string.substitute(this.messages.serverInfoWithRealm, ["<span>"+hostname+"</span>", "<span>"+realm+"</span>"]) : dojo.string.substitute(this.messages.serverInfo, ["<span>"+hostname+"</span>"]);
	},
	
	startup: function() {
		if(this.state === "login-failed" || !this.userId.attr('value')) {
			var focusNode = this.userId.domNode;
		} else {
			focusNode = this.password.domNode;
		}
		dijit.selectInputText(focusNode);
	},
	
	doLogIn: function(e) {
		var cookieVal = this.rememberUserId.attr('value') ? this.userId.attr('value') : "";
		jazz.app.internal.loginUtil.setUserIdCookie(cookieVal);
		
		if(!this.onSubmit) {
			return;
		}
		
		dojo.stopEvent(e);
		
		// run the callback in the global scope so that it doesn't have access to internal variables
		dojo.hitch(window, this.onSubmit, this.userId.attr('value'), this.password.attr('value'))();
		document.title = this._origWindowTitle;
	}
});
})();