/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2009. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("jazz.app.internal.Navbar");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dojo.i18n");
dojo.require("net.jazz.ajax.ui.PageList");
dojo.require("jazz.app.internal.ContextSwitcher");
dojo.require("jazz.app.internal.HoverMenu");
dojo.requireLocalization("jazz.app.internal", "NavbarMessages");

/**
 * Provides the web UI's header area.
 */
var ContextSwitcher = jazz.app.internal.ContextSwitcher;
var messages;

dojo.declare("jazz.app.internal.Navbar", [dijit._Widget, dijit._Templated], {
	
	templatePath: dojo.moduleUrl("jazz.app", "internal/templates/Navbar.html"),
	
	constructor: function () {
		this.messages = messages = dojo.i18n.getLocalization("jazz.app.internal", "NavbarMessages");
	},
	init: function(args) {
		if (args.usePageRegistry) {
			var pageList = new net.jazz.ajax.ui.PageList({suppressedPages: args.suppressedPages});
			this._leftLinks.appendChild(pageList.domNode);
		}
		if (args.contextSwitcher) {
			this._showContextSwitcher(args.contextSwitcher);
		}
		if (args.navbarItems) {
			this.navbarItems = args.navbarItems;
			for(var i = 0; i < this.navbarItems.length; i++) {
				this.navbarItems[i]._widget = this._createItem(this.navbarItems[i]);
			}		
		}
	},

	// Private functions
	_showContextSwitcher: function(contextSwitcherArgs, user) {
		if (user) {
			contextSwitcherArgs.admin = user.admin;	
		}
		this._projectSelector.appendChild(new ContextSwitcher(contextSwitcherArgs).domNode);
	},
	_createItem: function(args) {
		// Creates a link/menu, puts it in the navbar and returns a reference.
		// args: iconSrc, title, href, pageId, menuProvider, align: "left" (default) or "right"
		if (!args.label) {
			console.error("Error creating button: Must pass label param"); //$NON-NLS-1$
			return;
		}
		var label = args.label ? args.label : "";
		var button = document.createElement("a");
		if (args.pageId) {
			args.href = "#action=jazz.viewPage&id=" + args.pageId;
			if(args.isDefault && window.location.hash.indexOf("action") < 0) {
				window.location.href = args.href;
			}
			dojo.subscribe(net.jazz.ajax.internal.events.viewPage, this, function(page) {
				this._checkButtonHighlight(page, args.pageId, button);
			});
		}
		button.href = args.href ? args.href : "#";	
		if (!args.href && !args.pageId) {
			this.connect(button,"onclick",dojo.stopEvent);
			button.style.cursor = "default";
		}
		button.title = label;
		if (args.iconSrc) {
			var icon = document.createElement("img");
			icon.alt = label;
			icon.src = args.iconSrc;
			button.appendChild(icon);			
		}
		button.appendChild(document.createTextNode(label));
		if (args.align && args.align == "right") {
			this._rightLinks.appendChild(button);
		} else {
			this._leftLinks.appendChild(button);
		}
		if (args.rightPipe) {
			var pipe = document.createElement("div");
			pipe.className="pipe";
			pipe.innerHTML = "|";
			if (args.align && args.align == "right") {
				this._rightLinks.appendChild(pipe);
			} else {
				this._leftLinks.appendChild(pipe);
			}
		}
		if (args.selected) {
			dojo.addClass(button,"selected");
		}
		if (args.menuProvider) {
			new jazz.app.internal.HoverMenu({align: args.align, menuProvider: args.menuProvider, menuClass:"jazz-app-Navbar-menu"}, button);
		} else {
			dojo.addClass(button,"menu-narrow");
		}
		return button;
	},
	_checkButtonHighlight: function (page, pageId, button) {
		if (page.id === pageId) {
			dojo.addClass(button,"selected");
		} else {
			dojo.removeClass(button,"selected");
		}
	}
});

})();
