/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2009. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.repository.web.ui.internal.admin.server.FloatingLicenseReportView");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");

dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.client.internal.licensing");
dojo.require("com.ibm.team.repository.web.ui.internal.admin.server.FloatingLicenseTypeCombo");
dojo.require("com.ibm.team.repository.web.ui.internal.common.TimestampWidget");
dojo.require("com.ibm.team.repository.web.ui.wizard.WizardStepHeader");
dojo.require("net.jazz.ajax.ui.PlatformUI");
dojo.require("dojo.i18n");

dojo.requireLocalization("com.ibm.team.repository.web.ui.internal.admin.server", "FloatingLicenseReportViewMessages");
dojo.requireLocalization("com.ibm.team.repository.web.ui.internal.wizard", "SetupUsersMessages");

var REPO_BUNDLE = "com.ibm.team.repository.service";
var USAGE_PATH = "licenseReports/LicenseUsage.rptdesign";
var DENIALS_PATH = "licenseReports/LicenseDenials.rptdesign";
var COMPARISON_PATH = "licenseReports/LicenseUsageComparison.rptdesign";
var USAGE_CALLBACK = "processUsageReport";
var DENIALS_CALLBACK = "processDenialsReport";
var COMPARISON_CALLBACK = "processComparisonReport";
var FROM_TIME = "FROM_TIME";
var TO_TIME = "TO_TIME";
var START_KEY = 'startDate';
var END_KEY = 'endDate';

var REPORTS = [
	{bundle: REPO_BUNDLE, path: USAGE_PATH, callback: USAGE_CALLBACK, 
		params: [{name: 'Max Licenses', calValue: 'total'}, 
				{name: FROM_TIME, formValue: START_KEY },
				{name: TO_TIME, formValue: END_KEY}]
	},
	{bundle: REPO_BUNDLE, path: DENIALS_PATH, callback: DENIALS_CALLBACK, 
		params: [{name: FROM_TIME, formValue: START_KEY },
				{name: TO_TIME, formValue: END_KEY}]
	},
	{bundle: REPO_BUNDLE, path: COMPARISON_PATH, callback: COMPARISON_CALLBACK,
		params: [{name: FROM_TIME, formValue: START_KEY },
				{name: TO_TIME, formValue: END_KEY}]
	}
]

var REPORT_VIEW_STYLE = "reportView";	
		
var SRH	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var licensing = com.ibm.team.repository.web.client.internal.licensing;
var getReportHtml = licensing.getReportHtml;
var FloatingLicenseTypeCombo = com.ibm.team.repository.web.ui.internal.admin.server.FloatingLicenseTypeCombo;
var WizardStepHeader = com.ibm.team.repository.web.ui.wizard.WizardStepHeader;

function isNode(o){
	return o && o.nodeType && o.cloneNode;
}

function getWorkbench() {
	return net.jazz.ajax.ui.PlatformUI.getWorkbench();
}

function setText(e, text) {
	dojox.data.dom.removeChildren(e);
	
	if (!isNode(text)) {
		text = document.createTextNode(text);
	}
	
	e.appendChild(text);
}


dojo.declare("com.ibm.team.repository.web.ui.internal.admin.server.FloatingLicenseReportView", [dijit._Widget, dijit._Templated], {

	templatePath: dojo.moduleUrl("com.ibm.team.repository.web", "ui/internal/admin/server/templates/FloatingLicenseReportView.html"),

	constructor: function(args){
		this.messages = dojo.i18n.getLocalization("com.ibm.team.repository.web.ui.internal.admin.server", "FloatingLicenseReportViewMessages");
		this.showForm = args.showForm;
	},	
	
	postCreate: function() {
		com.ibm.team.repository.web.ui.internal.admin.server.FloatingLicenseReportView.superclass.postCreate.apply(this);		
		var self = this;

		this.header = new WizardStepHeader({ 
			stepTitle: this.messages.heading,
			reset: dojo.hitch(this,"refresh")
		});
		this.headerArea.appendChild(this.header.domNode);

		var onLoad = function(licenseId, licenseInfo) {
			self._handleTypeListLoad(licenseId, licenseInfo);
		}
				
		var onError = function(error) {
			self._handleServiceError(error);
		} 

		var floatHelper = {
			yes: function(status) {
				self._createReportViews();
				self._createForm();
				
				var params = {licenseId: self.licenseId,
							  onLoad: onLoad,
							  onError: onError}	
				self.typeCombo = new FloatingLicenseTypeCombo(params, self.licensePicker);
				
			},
			no: function(s) {
				setText(self.description, self.messages.notEnabled);  
			},
			error: function(err) {
				err.message = self.messages.failedFloatCheck + ": " + err.message;
				self._displayErrorMessage(err);
			}
		}
		
		licensing.checkFloatingLicensesSupported(floatHelper.yes, floatHelper.no, floatHelper.error);
	},
	
	refresh: function () {
		this.header.clearMessages();
	},

	_handleTypeListLoad: function(licenseId, licenseInfo) {
		if (!licenseId) {
			// No floating licenses are installed in the server
			var descNode = document.createElement("span");
			var floatinglink = "<a href='#action=com.ibm.team.repository.admin.manageLicenses&focusTab=floating'>";
			var installFloatingMessage = dojo.string.substitute(this.messages.installFloatingLink, [ floatinglink, "</a>" ]);
			descNode.innerHTML = installFloatingMessage;
			setText(this.description, descNode);
		} else {
			dojo.toggleClass(this.simpleViewArea, "noDisplay", false);
		}
	},
		
	_createForm: function () {
		var self = this;
		var args = {
			onChangeFunction: "_handleDateSelected", 
			parent: self
		};
		this.dateWidget1 = new com.ibm.team.repository.web.ui.internal.common.TimestampWidget(args);
		this.startDatePicker.appendChild(this.dateWidget1.domNode);
		
		var args = {
			onChangeFunction: "_handleDateSelected", 
			parent: self
		};
		this.dateWidget2 = new com.ibm.team.repository.web.ui.internal.common.TimestampWidget(args);
		this.endDatePicker.appendChild(this.dateWidget2.domNode);
		
		this.requestButton = document.createElement("button");
		var label = document.createTextNode(this.messages.buttonLabel);
		this.requestButton.appendChild(label);
		this.connect(this.requestButton, "onclick", "_fetchAllReports");
		this.buttonArea.appendChild(this.requestButton);
	},
	
	_handleDateSelected: function (date) {
		var error = false;
		if (this.dateWidget1.getDateValue() && this.dateWidget2.getDateValue() && this.dateWidget1.getDateValue() > this.dateWidget2.getDateValue()){
			error = true;
		} 
		dojo.toggleClass(this.dateErrorMsg, "noDisplay", !error);
		this.requestButton.disabled = error;
	},
	
	_createReportViews: function () {
		var allReportsView = document.createElement("div");
		allReportsView.className = "allReportsView";
		this.simpleViewArea.appendChild(allReportsView);
		
		this.usageReportView = document.createElement("div");
		this.usageReportView.className = REPORT_VIEW_STYLE;
		allReportsView.appendChild(this.usageReportView);
		
		this.denialReportView = document.createElement("div");
		this.denialReportView.className = REPORT_VIEW_STYLE;
		allReportsView.appendChild(this.denialReportView);
		
		this.comparisonReportView = document.createElement("div");
		this.comparisonReportView.className = REPORT_VIEW_STYLE;
		allReportsView.appendChild(this.comparisonReportView);
	},

	_fetchAllReports: function () {
		getWorkbench().showMessage(this.messages.loadingReportInfo);
		dojox.data.dom.removeChildren(this.usageReportView); 
		dojox.data.dom.removeChildren(this.denialReportView);
		dojox.data.dom.removeChildren(this.comparisonReportView);
		this.reportResponses = 0;
		this.requestButton.disabled = true;
		var self = this;
		var licenseId = this.typeCombo.licenseId;
		var licenseInfo = this.typeCombo.getLicenseById(licenseId);
		this.startDate = this.dateWidget1.getBirtValue();
		this.endDate = this.dateWidget2.getBirtValue();
		
		dojo.forEach(REPORTS, function(report) {
			var names = ["NAME"];
			var values = [licenseId];
			if (report.params) {
				dojo.forEach(report.params, function(param) {
					if (param.name && param.calValue && licenseInfo[param.calValue]) {
						names.push(param.name);
						values.push(licenseInfo[param.calValue]);
					}
					if (param.name && param.formValue && self[param.formValue]) {
						names.push(param.name);
						values.push(self[param.formValue]);
					}
				});
			}
			
			var args = {
				bundle: report.bundle, 
				path: report.path, 
				parameterName: names,
				parameterValue: values,
				showArchived: "false", 
				urlPrefix: window.location.protocol + "//" + window.location.hostname + ":" + window.location.port + net.jazz.ajax._contextRoot + "/"			
			}
			self._invokeReport(args, report.callback);
		});
	},
	
	_invokeReport: function(args, success) {
		getReportHtml(new SRH(this, success, "_handleServiceError"), args);
	},
	
	VIEWS: {
		processUsageReport: "usageReportView", 
		processDenialsReport: "denialReportView",
		processComparisonReport: "comparisonReportView"
	},
	
	processUsageReport: function(htmlReport) {
		this.handleResponseCount();
		this._displayReportInfo(htmlReport, this[this.VIEWS["processUsageReport"]]);
	},
	
	processDenialsReport: function(htmlReport) {
		this.handleResponseCount();
		this._displayReportInfo(htmlReport, this[this.VIEWS["processDenialsReport"]]);
	},

	processComparisonReport: function(htmlReport) {
		this.handleResponseCount();
		this._displayReportInfo(htmlReport, this[this.VIEWS["processComparisonReport"]]);
	},

	handleResponseCount: function() {
		this.reportResponses++;
		if (this.reportResponses === REPORTS.length) {
			this.requestButton.disabled = false;
			getWorkbench().hideMessageArea();
		}
	},
	
	_displayReportInfo: function(htmlReport, displayIn) {
		this._clearMessages();
		dojox.data.dom.removeChildren(displayIn);
		 
		var reportDiv = document.createElement("div");	
		reportDiv.innerHTML = htmlReport;
		displayIn.appendChild(reportDiv);
	},
	
	_handleServiceError: function(errorObj) {
		this.handleResponseCount();
		this._displayErrorMessage(errorObj);
	},	

	_displayErrorMessage: function(errorObj) {
		this.header.displayServiceCallbackErrorMessage(errorObj);
	},
	
	_clearMessages: function () {
		this.header.clearMessages();
	}

});

})();