/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2008. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("net.jazz.ajax.service.ui.internal.userdata.UserDataManager");

dojo.require("net.jazz.ajax.ui.MappingUI");
dojo.require("net.jazz.ajax.ui.PlatformUI");
dojo.require("net.jazz.ajax.ui.Workbench");
dojo.require("net.jazz.ajax.service.ui.userdata.util");

dojo.require("jazz.client.xhr");

var PlatformUI = net.jazz.ajax.ui.PlatformUI;
var GLOBAL_NAV = "net.jazz.ajax.GlobalNav";

function getTagString(entry) {
	var tagString = "";
	if (entry["rdf:Description"].tag) {
		var tags = [];
		for (var i = 0; i < entry["rdf:Description"].tag.length; i++) {
			tags.push(entry["rdf:Description"].tag[i].value);
		}
		tagString = tags.join(", ");
	}
	return tagString;
}

dojo.declare("net.jazz.ajax.service.ui.internal.userdata.UserDataManager", [dijit._Widget, dijit._Templated], {
	templatePath: dojo.moduleUrl("net.jazz.ajax.service", "ui/internal/userdata/templates/UserDataManager.html"),
	
	constructor: function (args) {
		this._userId = net.jazz.ajax.service.ui.userdata.util.getLoggedInUser();
	},
	
	postCreate: function() {
		this.inherited(arguments);
		var pathInfo = net.jazz.ajax.ui.MappingUI._getPathInfo();
		net.jazz.ajax.service.ui.userdata.util.addHistory({
			uri: pathInfo
		});
		this.userData = [];
		
		this.connect(this.selectAllBox, "onclick", function (e) {
			dojo.forEach(this.userDataTable.rows, dojo.hitch(this, function(curRow) {
				curRow.rowSelector.checked = this.selectAllBox.checked;
			}));
		});
		
		// add RSS feed link
		if (this._userId != null) {
			var link = document.createElement("link");
			link.rel = "alternate";
			link.type = "application/atom+xml";
			link.title = this._dataType;
			link.href = "/_userdata/" + this._userId + "/" + this._dataType.toLowerCase();
			this.managerDiv.appendChild(link);
		}
	},
	
	getSelectedRows: function () {
		var selectedRows = [];
		for (var i=0; i < this.userDataTable.rows.length; i++) {
			if (this.userDataTable.rows[i].rowSelector.checked) {
				selectedRows.push(this.userDataTable.rows[i]);
			}
		}
		return selectedRows;
	},
	
	getSelectedUris: function () {
		var selectedUris = [];
		for (var i=0; i < this.userDataTable.rows.length; i++) {
			if (this.userDataTable.rows[i].rowSelector.checked) {
				selectedUris.push(this.userDataTable.rows[i].rowSelector.dataHref);
			}
		}
		return selectedUris;
	},
	
	processResponse: function (response, itemType) {
		this.userData = [];
		if (response.entry) {
			for (var i=0; i < response.entry.length; i++) {
				var curEntry = response.entry[i];
				if (curEntry.type != null && curEntry.type !== "favorite") {
					continue;
				}
				var tagString = getTagString(curEntry);
				this.userData.push({
					uri: curEntry["rdf:Description"][0]["group:link"][0]["rdf:Description"][0][itemType][0]["rdf:resource"],
					title: curEntry["rdf:Description"][0].title[0].value,
					comments: curEntry["rdf:Description"][0].comments[0].value,
					tags: tagString
				});
			}
		}
		this.populate();
	},
	
	processResponseErr: function (response, type) {
		this.userData = [];
		// TODO - display user-friendly error message
		alert("An error occurred retrieving your " + type + ": " + err);
	},
	
	populate: function () {
		dojox.data.dom.removeChildren(this.userDataTable);
		dojo.forEach(this.userData, dojo.hitch(this, function (curData) {
			var tr = document.createElement("tr");
			var checkboxCell = document.createElement("td");
			dojo.toggleClass(checkboxCell, "nowrap", true);
			var checkbox = document.createElement("input");
			tr.rowSelector = checkbox;
			checkbox.type = "checkbox";
			checkbox.dataHref = curData.uri;
			checkboxCell.appendChild(checkbox);
			var editLink = document.createElement("a");
			editLink.href = "/_ajax-modules/" + GLOBAL_NAV + "/" + this._EDITOR + "/" + curData.uri;
			editLink.appendChild(document.createTextNode("Edit"));
			editLink.style.marginLeft = "15px";
			checkboxCell.appendChild(editLink);
			var pathCell = document.createElement("td");
			var link = document.createElement("a");
			link.href = curData.uri;
			link.appendChild(document.createTextNode(curData.uri));
			pathCell.appendChild(link);
			var titleCell = document.createElement("td");
			titleCell.appendChild(document.createTextNode(curData.title || ""));
			var commentsCell = document.createElement("td");
			commentsCell.appendChild(document.createTextNode(curData.comments || ""));
			var tagsCell = document.createElement("td");
			tagsCell.appendChild(document.createTextNode(curData.tags || ""))
			tr.appendChild(checkboxCell);
			tr.appendChild(pathCell);
			tr.appendChild(titleCell);
			tr.appendChild(commentsCell);
			tr.appendChild(tagsCell);
			this.userDataTable.appendChild(tr);
		}))
	}
});
})();