/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2008, 2009 All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("com.ibm.team.repository.web.ui.wizard.WizardStepHeader");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("com.ibm.team.repository.web.ui.wizard.WizardStep");
dojo.require("jazz.app.ua.PageHoverHelp");

dojo.require("dojo.i18n");
dojo.requireLocalization("com.ibm.team.repository.web.ui.wizard", "WizardMessages");
	
(function() {

var WizardStep = com.ibm.team.repository.web.ui.wizard.WizardStep;

var messages;
var clearNodes = dojox.data.dom.removeChildren;
var NO_DISPLAY = "noDisplay";

dojo.declare("com.ibm.team.repository.web.ui.wizard.WizardStepHeader", [WizardStep, dijit._Widget, dijit._Templated], {
	
	reset: null, // provide a reset function in the step constructor to display the reset icon
	helpContent: null, // provide a string to display in the help hover to display the help icon
	
	templatePath: dojo.moduleUrl("com.ibm.team.repository.web", "ui/wizard/templates/WizardStepHeader.html"),
	
	constructor: function() {
		this.messages = messages = dojo.i18n.getLocalization("com.ibm.team.repository.web.ui.wizard", "WizardMessages");
		this.stepTitle = this.stepTitle ? this.stepTitle : "";
	},

	postCreate: function() {
		if (this.helpContent) {
			var help = new jazz.app.ua.PageHoverHelp({contentString: this.helpContent});
			this.helpArea.appendChild(help.domNode);
		}
		if (this.reset && dojo.isFunction(this.reset)){
			dojo.connect(this.resetArea, "onclick", this, "reset");
			dojo.toggleClass(this.resetArea, NO_DISPLAY, false);
		}	
		dojo.toggleClass(this.messageArea, NO_DISPLAY, true);
	},

	/* Expects a message argument of the format:
	 *  message = {
	 *  	type: <value from STATUS_TYPES enum>,
	 *  	summary: <string message or element>,
	 *  	details: <string details> (optional)
	 *    isDomNode:  <boolean> (optional>
	 *  }
	 */
	showStatus: function(message) {
		if (!message.summary && !message.type) {
			return; // early return
		}
		clearNodes(this.messageArea);
		this.messageArea.className = "messageArea " + message.type + " " + message.type + "-color"
		if (message.isDomNode) {
			this.messageArea.appendChild(message.summary);
		}
		else {
			var node = document.createElement("span");
			node.innerHTML = message.summary;
			this.messageArea.appendChild(node);
			
			if (message.details && message.details.length > 0) {				
				//Build detailsLink
				this.detailsLink = document.createElement("a");
				dojo.connect(this.detailsLink, "onclick", this, "toggleDetails");
				this.detailsLink.className = "detailsLink";
				this.detailsLink.setAttribute('id', "details-box");
				this.detailsLink.innerHTML = this.messages.showDetails;
				this.messageArea.appendChild(this.detailsLink);
				
				//Holds all of the individual detailed messages
				this.detailsBox = document.createElement("div");
				this.messageArea.appendChild(this.detailsBox);
				dojo.addClass(this.detailsBox,"detailsBox");
				
				//Get the actual details
				for (var i = 0; i < message.details.length; i++) {
					var msg = document.createElement("div");
					msg.innerHTML = message.details[i].message;
					msg.className = "messageDetails " + message.details[i].code + "-color";
					this.detailsBox.appendChild(msg);
				}
			}
		}
		
		dojo.toggleClass(this.messageArea, NO_DISPLAY, false);
	}, 

	toggleDetails: function() {
		if(this.detailsBox.style.display == "block") {
			//close it
			this.detailsBox.style.display = "none";
			this.detailsLink.innerHTML = this.messages.showDetails;
		} else {
			//open it
			this.detailsBox.style.display = "block";
			this.detailsLink.innerHTML = this.messages.hideDetails;
		}
	},
		
	clearMessages: function () {
		clearNodes(this.messageArea);
		dojo.toggleClass(this.messageArea, NO_DISPLAY, true);
	},
	
	displayServiceCallbackErrorMessage: function(errorObj, clientContextMessage) {
		var error = com.ibm.team.repository.web.ui.wizard.WizardStepHeader.STATUS_TYPES.ERROR;
		var status = {};
		status.type = error;
		if (errorObj && errorObj.status === 0) {
			status.summary = this.messages.serverUnreachable;
		} else {
			// let the caller pass in an optional context message specific to client code to override the errorObj.message
			status.summary = clientContextMessage ? clientContextMessage : errorObj.message ? errorObj.message : this.messages.unspecifiedServerError;
			status.details = [];
			if (clientContextMessage && errorObj.message) {
				// if there is a context message, show the errorObj message in the details block
				status.details.push({message: errorObj.message, code: error});
			}
			if (errorObj.errorClass) {
				status.details.push({message: errorObj.errorClass, code: error});	
			}
			if (errorObj.exception) {
				if (dojo.isArray(errorObj.exception)) {
					var detail = errorObj.exception.join("<br>");
				} else {
					detail = errorObj.exception;
				}
				status.details.push({message: detail, code: error});
			}
		}	
		this.showStatus(status);
	}, 
	
	showTimestamp: function() {
		clearNodes(this.loadedTimestampArea);
		var nowTime = dojo.date.locale.format(new Date());
		var timestamp = dojo.string.substitute(this.messages.loadedTimestamp, [nowTime]);
		this.loadedTimestampArea.appendChild(document.createTextNode(timestamp));
		dojo.toggleClass(this.loadedTimestampArea, NO_DISPLAY, false);
	}
});

com.ibm.team.repository.web.ui.wizard.WizardStepHeader.STATUS_TYPES = {
	ERROR: "ERROR",
	WARNING: "WARNING", 
	OK: "OK", 
	INFO: "INFO"
};

})();